@@ -5,18 +5,15 @@
 #' takes the appropriate action if this is the case (warning, error, or ignore,
 #' depending on the general option set via [lost_tags_action()]) .
 #'
+#' @inheritParams base::Extract
 #' @param x a `linelist` object
-#'
 #' @param i a vector of `integer` or `logical` to subset the rows of the
 #'   `linelist`
-#'
 #' @param j a vector of `character`, `integer`, or `logical` to subset the
 #'   columns of the `linelist`
-#'
 #' @param drop a `logical` indicating if, when a single column is selected, the
 #'   `data.frame` class should be dropped to return a simple vector, in which
 #'   case the `linelist` class is lost as well; defaults to `FALSE`
-#'
 #' @param value the replacement to be used for the entries identified in `x`
 #'
 #' @return If no drop is happening, a `linelist`. Otherwise an atomic vector.
@@ -32,8 +29,6 @@
 #'
 #' @aliases sub_linelist
 #'
-#' @author Thibaut Jombart \email{thibaut@@data.org}
-#'
 #' @examples
 #' if (require(outbreaks) && require(dplyr) && require(magrittr)) {
 #'   ## create a linelist
@@ -56,6 +51,9 @@
 #'
 #'   x[[2]] <- NULL
 #'   x
+#'
+#'   x$age <- NULL
+#'   x
 #' }
 `[.linelist` <- function(x, i, j, drop = FALSE) {
   # Strategy for subsetting
@@ -97,7 +95,7 @@
   }
 
   # Case 2
-  old_tags <- tags(x, TRUE)
+  old_tags <- tags(x, show_null = TRUE)
   out <- restore_tags(out, old_tags, lost_action)
 
   out
@@ -110,7 +108,7 @@
 `[<-.linelist` <- function(x, i, j, value) {
   lost_action <- get_lost_tags_action()
   out <- NextMethod()
-  old_tags <- tags(x, TRUE)
+  old_tags <- tags(x, show_null = TRUE)
   out <- restore_tags(out, old_tags, lost_action)
   out
 }
@@ -122,7 +120,18 @@
 `[[<-.linelist` <- function(x, i, j, value) {
   lost_action <- get_lost_tags_action()
   out <- NextMethod()
-  old_tags <- tags(x, TRUE)
+  old_tags <- tags(x, show_null = TRUE)
+  out <- restore_tags(out, old_tags, lost_action)
+  out
+}
+
+#' @export
+#'
+#' @rdname sub_linelist
+`$<-.linelist` <- function(x, name, value) {
+  lost_action <- get_lost_tags_action()
+  out <- NextMethod()
+  old_tags <- tags(x, show_null = TRUE)
   out <- restore_tags(out, old_tags, lost_action)
   out
 }
